@@ -1,6 +1,6 @@
 package Google::RestApi::SheetsApi4;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.1.0';
 
 use Google::RestApi::Setup;
 
@@ -22,10 +22,13 @@ Readonly our $Spreadsheet_Filter => "mimeType = 'application/vnd.google-apps.spr
 sub new {
   my $class = shift;
 
-  state $check = compile_named(
-    api           => HasApi,                                           # the G::RestApi object that will be used to send http calls.
-    drive         => HasMethods[qw(list)], { optional => 1 },  # a drive instnace, could be your own, defaults to G::R::DriveApi3.
-    endpoint      => Str, { default => $Sheets_Endpoint },              # this gets tacked on to the api uri to reach the sheets endpoint.
+  state $check = signature(
+    bless => !!0,
+    named => [
+      api           => HasApi,                                           # the G::RestApi object that will be used to send http calls.
+      drive         => HasMethods[qw(list)], { optional => 1 },  # a drive instnace, could be your own, defaults to G::R::DriveApi3.
+      endpoint      => Str, { default => $Sheets_Endpoint },              # this gets tacked on to the api uri to reach the sheets endpoint.
+    ],
   );
   my $self = $check->(@_);
 
@@ -37,9 +40,12 @@ sub new {
 # sheets endpoint and pass it up the line to G::RestApi to make the actual call.
 sub api {
   my $self = shift;
-  state $check = compile_named(
-    uri     => Str, { default => '' },
-    _extra_ => slurpy Any,              # just pass through any extra params to G::RestApi::api call.
+  state $check = signature(
+    bless => !!0,
+    named => [
+      uri     => Str, { default => '' },
+      _extra_ => slurpy HashRef,              # just pass through any extra params to G::RestApi::api call.
+    ],
   );
   my $p = named_extra($check->(@_));
   my $uri = $self->{endpoint};          # tack on the uri endpoint and pass the buck.
@@ -50,10 +56,13 @@ sub api {
 sub create_spreadsheet {
   my $self = shift;
 
-  state $check = compile_named(
-    title   => Str, { optional => 1 },
-    name    => Str, { optional => 1 },
-    _extra_ => slurpy Any,
+  state $check = signature(
+    bless => !!0,
+    named => [
+      title   => Str, { optional => 1 },
+      name    => Str, { optional => 1 },
+      _extra_ => slurpy HashRef,
+    ],
   );
   my $p = named_extra($check->(@_));
   # we allow name and title to be synonymous for convenience. it's actuall title in the google api.
@@ -78,9 +87,12 @@ sub create_spreadsheet {
 sub copy_spreadsheet {
   my $self = shift;
   my $id = $Spreadsheet_Id;
-  state $check = compile_named(
-    spreadsheet_id => StrMatch[qr/$id/],
-    _extra_        => slurpy Any,
+  state $check = signature(
+    bless => !!0,
+    named => [
+      spreadsheet_id => StrMatch[qr/$id/],
+      _extra_        => slurpy HashRef,
+    ],
   );
   my $p = named_extra($check->(@_));
   my $file_id = delete $p->{spreadsheet_id};
@@ -92,7 +104,7 @@ sub copy_spreadsheet {
 sub delete_spreadsheet {
   my $self = shift;
   my $id = $Spreadsheet_Id;
-  state $check = compile(StrMatch[qr/$id/]);
+  state $check = signature(positional => [StrMatch[qr/$id/]]);
   my ($spreadsheet_id) = $check->(@_);
   return $self->drive()->file(id => $spreadsheet_id)->delete();
 }
@@ -100,12 +112,12 @@ sub delete_spreadsheet {
 sub delete_all_spreadsheets_by_filters {
   my $self = shift;
 
-  state $check = compile(ArrayRef->plus_coercions(Str, sub { [$_]; }));
+  state $check = signature(positional => [ArrayRef->plus_coercions(Str, sub { [$_]; })]);
   my ($filter) = $check->(@_);
 
   my $count = 0;
   foreach my $filter (@$filter) {
-    my @spreadsheets = $self->spreadsheets_by_filter($filter);
+    my @spreadsheets = $self->spreadsheets_by_filter(filter => $filter);
     $count += scalar @spreadsheets;
     DEBUG(sprintf("Deleting %d spreadsheets for filter '$filter'", scalar @spreadsheets));
     $self->delete_spreadsheet($_->{id}) foreach (@spreadsheets);
@@ -116,27 +128,52 @@ sub delete_all_spreadsheets_by_filters {
 sub delete_all_spreadsheets {
   my $self = shift;
   my @names = @_;
-  @names = map { "name = '$_"; } @names;
+  @names = map { "name = '$_'"; } @names;
   return $self->delete_all_spreadsheets_by_filters(@names);
 }
 
 sub spreadsheets_by_filter {
   my $self = shift;
 
-  state $check = compile(Optional[Str]);
-  my ($extra_filter) = $check->(@_);
+  state $check = signature(
+    bless => !!0,
+    named => [
+      filter        => Str, { optional => 1 },
+      max_pages     => Int, { default => 0 },
+      page_callback => CodeRef, { optional => 1 },
+      params        => HashRef, { default => {} },
+    ],
+  );
+  my $p = $check->(@_);
 
   my $drive = $self->drive();
   my $filter = $Spreadsheet_Filter;
-  $filter .= " and ($extra_filter)" if $extra_filter;
-  return $drive->list(filter => $filter);
+  $filter .= " and ($p->{filter})" if $p->{filter};
+  return $drive->list(
+    filter    => $filter,
+    max_pages => $p->{max_pages},
+    params    => $p->{params},
+    ($p->{page_callback} ? (page_callback => $p->{page_callback}) : ()),
+  );
 }
 
 sub spreadsheets {
   my $self = shift;
-  my ($name) = @_;
-  $name = "name = '$name'" if $name;
-  return $self->spreadsheets_by_filter($name);
+
+  state $check = signature(
+    bless => !!0,
+    named => [
+      name          => Str, { optional => 1 },
+      max_pages     => Int, { default => 0 },
+      page_callback => CodeRef, { optional => 1 },
+      params        => HashRef, { default => {} },
+    ],
+  );
+  my $p = $check->(@_);
+
+  my $name = delete $p->{name};
+  $p->{filter} = "name = '$name'" if $name;
+  return $self->spreadsheets_by_filter(%$p);
 }
 
 sub drive {
@@ -425,9 +462,52 @@ Deletes all spreadsheets with the given names from Google Drive.
 
 Returns the number of spreadsheets deleted.
 
-=item spreadsheets();
+=item spreadsheets(%args);
 
-Returns a list of spreadsheets in Google Drive.
+Lists spreadsheets in Google Drive, optionally filtered by name.
+
+%args consists of:
+
+=over
+
+=item * C<name> <string>: Optional. Filter by spreadsheet name.
+
+=item * C<max_pages> <int>: Optional. Maximum pages to fetch (default 0 = unlimited).
+
+=item * C<page_callback> <coderef>: Optional. Called with the result hashref for each page. Return false to stop pagination. See L<Google::RestApi/PAGE CALLBACKS>.
+
+=item * C<params> <hashref>: Optional. Additional query parameters passed to the Drive API.
+
+=back
+
+Returns a list of spreadsheet hashrefs.
+
+=item spreadsheets_by_filter(%args);
+
+Lists spreadsheets matching the given Drive query filter, combined with the
+spreadsheet MIME type filter.
+
+%args consists of:
+
+=over
+
+=item * C<filter> <string>: Optional. A Drive query filter string.
+
+=item * C<max_pages> <int>: Optional. Maximum pages to fetch (default 0 = unlimited).
+
+=item * C<page_callback> <coderef>: Optional. Called with the result hashref for each page. Return false to stop pagination. See L<Google::RestApi/PAGE CALLBACKS>.
+
+=item * C<params> <hashref>: Optional. Additional query parameters passed to the Drive API.
+
+=back
+
+Returns a list of spreadsheet hashrefs.
+
+=item delete_all_spreadsheets(name<string>, ...);
+
+Deletes all spreadsheets with the given names from Google Drive.
+
+Returns the number of spreadsheets deleted.
 
 =item drive();
 
@@ -439,6 +519,22 @@ Opens a new spreadsheet from the given id, uri, or name.
 
 %args consists of any args passed to Spreadsheet->new routine (which see).
 
+=item transaction();
+
+Returns the last API transaction details (delegates to L<Google::RestApi>).
+
+=item stats();
+
+Returns API call statistics (delegates to L<Google::RestApi>).
+
+=item reset_stats();
+
+Resets API call statistics (delegates to L<Google::RestApi>).
+
+=item rest_api();
+
+Returns the underlying L<Google::RestApi> instance.
+
 =back
 
 =head1 REQUEST CLASSES
