@@ -1,17 +1,20 @@
 package Google::RestApi::SheetsApi4::Range::Iterator;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.1.0';
 
 use Google::RestApi::Setup;
 
 sub new {
   my $class = shift;
-  state $check = compile_named(
-    range => HasMethods[qw(range worksheet)],
-    dim   => StrMatch[qr/^(col|row)$/], { default => 'row' },
-    by    => PositiveInt, { default => 1 },
-    from  => PositiveOrZeroInt, { optional => 1 },
-    to    => PositiveOrZeroInt, { optional => 1 },
+  state $check = signature(
+    bless => !!0,
+    named => [
+      range => HasMethods[qw(range worksheet)],
+      dim   => StrMatch[qr/^(col|row)$/], { default => 'row' },
+      by    => PositiveInt, { default => 1 },
+      from  => PositiveOrZeroInt, { optional => 1 },
+      to    => PositiveOrZeroInt, { optional => 1 },
+    ],
   );
   my $self = $check->(@_);
   $self->{current} = delete $self->{from} || 0;
