@@ -3,7 +3,7 @@ package Google::RestApi::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.1.0';
 
 use feature 'state';
 
@@ -13,8 +13,8 @@ use File::Basename qw( dirname );
 use Hash::Merge ();
 use Log::Log4perl qw( :easy );
 use Scalar::Util qw( blessed );
-use Type::Params qw( compile compile_named );
-use Types::Standard qw( Str StrMatch Int CodeRef HashRef Any slurpy );
+use Type::Params qw( signature );
+use Types::Standard qw( Str StrMatch Int CodeRef HashRef HasMethods Any slurpy );
 use YAML::Any qw( Dump LoadFile );
 
 use Google::RestApi::Types qw( ReadableFile );
@@ -27,10 +27,11 @@ our @EXPORT_OK = qw(
   merge_config_file resolve_config_file_path
   flatten_range
   bool
-  dim_any dims_any dims_all
+  dims_any dims_all
   cl_black cl_white
   strip
   paginate_api
+  paginated_list
 );
 our %EXPORT_TAGS = (all => [ @EXPORT_OK ]);
 
@@ -39,11 +40,16 @@ our %EXPORT_TAGS = (all => [ @EXPORT_OK ]);
 # extra key/value pairs we aren't interested in in the checked
 # argument hash.
 sub named_extra {
-  state $check = compile_named(
-    _extra_   => HashRef,
-    validated => slurpy HashRef,
+  # v2 signature returns blessed hashref; dereference if needed.
+  my @args = @_ == 1 && ref $_[0] ? %{$_[0]} : @_;
+  state $check = signature(
+    bless => !!0,
+    named => [
+      _extra_   => HashRef,
+      validated => slurpy HashRef,
+    ],
   );
-  my $p = $check->(@_);
+  my $p = $check->(@args);
   my $extra = delete $p->{_extra_};
 
   my %p;
@@ -53,9 +59,12 @@ sub named_extra {
 }
 
 sub merge_config_file {
-  state $check = compile_named(
-    config_file => ReadableFile, { optional => 1 },
-    _extra_     => slurpy Any,
+  state $check = signature(
+    bless => !!0,
+    named => [
+      config_file => ReadableFile, { optional => 1 },
+      _extra_     => slurpy HashRef,
+    ],
   );
   my $passed_config = named_extra($check->(@_));
 
@@ -77,7 +86,7 @@ sub merge_config_file {
 # to a full path. can be used in Auth configs, possibly others.
 # see sub RestApi::auth for more.
 sub resolve_config_file_path {
-  state $check = compile(HashRef, Str);
+  state $check = signature(positional => [HashRef, Str]);
   my ($config, $file_key) = $check->(@_);
 
   my $config_file = $config->{$file_key} or return;
@@ -142,7 +151,7 @@ sub bool {
 }
 
 sub dims_any {
-  state $check = compile(StrMatch[qr/^(col|row)/i]);
+  state $check = signature(positional => [StrMatch[qr/^(col|row)/i]]);
   my ($dims) = $check->(@_);
   return $dims =~ /^col/i ? "COLUMNS" : "ROWS";
 }
@@ -150,7 +159,7 @@ sub dims_any {
 sub dims_all {
   my $dims = eval { dims_any(@_); };
   return $dims if $dims;
-  state $check = compile(StrMatch[qr/^all/i]);
+  state $check = signature(positional => [StrMatch[qr/^all/i]]);
   ($dims) = $check->(@_);
   return "ALL";
 }
@@ -165,11 +174,14 @@ sub strip {
 }
 
 sub paginate_api {
-  state $check = compile_named(
-    api_call       => CodeRef,
-    result_key     => Str,
-    max_pages      => Int, { default => 0 },
-    page_callback  => CodeRef, { optional => 1 },
+  state $check = signature(
+    bless => !!0,
+    named => [
+      api_call       => CodeRef,
+      result_key     => Str,
+      max_pages      => Int, { default => 0 },
+      page_callback  => CodeRef, { optional => 1 },
+    ],
   );
   my $p = $check->(@_);
 
@@ -191,4 +203,32 @@ sub paginate_api {
   return @list;
 }
 
+sub paginated_list {
+  state $check = signature(
+    bless => !!0,
+    named => [
+      api            => HasMethods['api'],
+      uri            => Str,
+      result_key     => Str,
+      default_fields => Str,
+      fields_prefix  => Str, { default => 'nextPageToken' },
+      max_pages      => Int, { default => 0 },
+      page_callback  => CodeRef, { optional => 1 },
+      params         => HashRef, { default => {} },
+    ],
+  );
+  my $p = $check->(@_);
+  my $params = $p->{params};
+  $params->{fields} //= $p->{default_fields};
+  $params->{fields} = "$p->{fields_prefix}, $params->{fields}";
+  my $api = $p->{api};
+  my $uri = $p->{uri};
+  return paginate_api(
+    api_call   => sub { $params->{pageToken} = $_[0] if $_[0]; $api->api(uri => $uri, params => $params); },
+    result_key => $p->{result_key},
+    max_pages  => $p->{max_pages},
+    ($p->{page_callback} ? (page_callback => $p->{page_callback}) : ()),
+  );
+}
+
 1;
